/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter, Indiana University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that: (1) source distributions retain this entire copyright
 * notice and comment, and (2) distributions including binaries display
 * the following acknowledgement:  ``This product includes software
 * developed by Indiana University '' in the documentation or other
 * materials provided with the distribution and in all advertising
 * materials mentioning features or use of this software. The
 * name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * MODULE:
 *	Virtual clock generator
 *
 * FILE:
 *	clock.c
 *
 * ABSTRACT:
 *	Periodically broadcast the current virtual time in seconds from module
 *	start.
 *
 * $Revision: 1.4 $
 * $Date: 1996/01/17 18:55:41 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: clock.c,v $
 * Revision 1.4  1996/01/17  18:55:41  jla
 * Updated Copyright verbage in preparation for release.
 *
 * Revision 1.3  1996/01/16  17:54:25  jla
 * Fixed time scale message.
 *
 * Revision 1.2  1996/01/16  17:36:16  jla
 * Clock now broadcasts only every other second.  This lightens the
 * simulator traffic a bit.
 *
 * Also, the step increment is in terms of TWO seconds.  E.g.
 * 1:	1/2 real time
 * 2:	real time
 * 3:	1.5 faster than real
 * 4:	twice real
 *
 * Revision 1.1  1996/01/12  17:42:10  jla
 * Initial revision
 *
 *
 */


#include <stdio.h>
#include "tca.h"

#include "clock.h"

#define MODULE	"Clock Module"

char *program;		/* record argv[0] for error messages */

int time;		/* current virtual time */
int step;		/* amount to increment virtual time */


main(int argc, char **argv)
{
   program = argv[0];
   time = 0;
   step = 1;

   printf("%s starting up...\n", MODULE);

   if(argc > 2) {
      fprintf(stderr, "Usage: %s [time_scale]\n",program);
      exit(-1);
   }

   if(argc > 1) {
      step = atoi(argv[1]);
   }

   printf("Time scale is %d:2\n",step);

   printf("Connect...\n");
   tcaConnectModule(MODULE, tcaServerMachine());

   tcaRegisterBroadcastMessage(ClockBroadcast, ClockFormat);

   tcaWaitUntilReady();

   printf("Elapsed Time: 00:00:00");
   for(;;) {
      int h,m,s;
      
      time += (step/2);
      s = time % 60;
      m = (time / 60) % 60;
      h = time / 3600;
      printf("\b\b\b\b\b\b\b\b%02d:%02d:%02d", h, m, s);fflush(stdout);
      sleep(1);

      time += (step/2 + step%2);
      s = time % 60;
      m = (time / 60) % 60;
      h = time / 3600;
      printf("\b\b\b\b\b\b\b\b%02d:%02d:%02d", h, m, s);fflush(stdout);
      tcaBroadcast(ClockBroadcast, &time);
      sleep(1);
   }
      
}
