/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter, Indiana University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that: (1) source distributions retain this entire copyright
 * notice and comment, and (2) distributions including binaries display
 * the following acknowledgement:  ``This product includes software
 * developed by Indiana University '' in the documentation or other
 * materials provided with the distribution and in all advertising
 * materials mentioning features or use of this software. The
 * name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * MODULE:
 *	Robot controller/simulator.
 *
 * FILE:
 *	motor.h
 *
 * ABSTRACT:
 *	Defines message types.
 *	Defines physical colony parameters.
 *
 * $Revision: 1.4 $
 * $Date: 1996/01/17 19:01:03 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: motor.h,v $
 * Revision 1.4  1996/01/17  19:01:03  jla
 * Updated Copyright verbage in preparation for release.
 *
 * Revision 1.3  1996/01/16  20:05:00  jla
 * Added minimal access control to robots.
 *
 * Revision 1.2  1996/01/15  14:01:29  jla
 * Enrolling in version control.
 *
 *
 */


#ifndef _MOTOR_
#define _MOTOR_

#define	ROBOT_RADIUS	9.00	/* in cm */
#define COLONY_SIZE	122.0	/* size of the colony in cm */

#define MAX_ROBOTS	6
#define WEST_WALL	-COLONY_SIZE*0.5
#define EAST_WALL	COLONY_SIZE*0.5
#define NORTH_WALL	COLONY_SIZE*0.5
#define SOUTH_WALL	-COLONY_SIZE*0.5

#define CMD_STOP	0
#define CMD_F		1
#define CMD_FL		2
#define CMD_FR		3
#define CMD_R		4
#define CMD_RL		5
#define CMD_RR		6
#define CMD_LED_ON	7
#define CMD_LED_OFF	8

typedef	struct {
   int robot;
   int cookie;
   int cmd;
} RobotCmdType, *RobotCmdPtr;

#define RobotCmd	"RobotCmd"
#define RobotCmdFormat	"{int, int, int}"

#define RobotGlobalCmd	"RobotGlobalCmd"
#define RobotGlobalCmdFormat	"int"

typedef struct{
	char *ident;
	char *pass;
} IdentT, *IdentPtr;

typedef struct{
	int number;
	int cookie;
} CookieT, *CookiePtr;

#define IncarnateQuery		"IncarnateQuery"
#define IncarnateQueryFormat	"{string, string}"
#define IncarnateQueryReplyFmt	"{int, int}"
#endif /* _MOTOR_ */
