/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter, Indiana University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that: (1) source distributions retain this entire copyright
 * notice and comment, and (2) distributions including binaries display
 * the following acknowledgement:  ``This product includes software
 * developed by Indiana University '' in the documentation or other
 * materials provided with the distribution and in all advertising
 * materials mentioning features or use of this software. The
 * name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * MODULE:
 *	Vision simulator
 *
 * FILE:
 *	visionsim.c
 *
 * ABSTRACT:
 *	receive messages from motor sim and pretend to do vision to
 *	locate the robots
 *
 * $Revision: 1.3 $
 * $Date: 1996/01/17 19:20:17 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: visionsim.c,v $
 * Revision 1.3  1996/01/17  19:20:17  jla
 * Updated Cogyright verbage for release.
 *
 * Revision 1.2  1996/01/15  16:52:17  jla
 * Enrolling in version control.
 *
 *
 */


#include <stdio.h>
#include "tca.h"
#include "../GPS/gps.h"
#include "visionsim.h"

#define MODULE	"VisionSim Module"

CoordArray coord;	/* for messages */

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void visionInformHnd(TCA_REF_PTR ref, CoordArrayPtr c)
 *
 * DESCRIPTION:
 *	update the locations of the robots (from motor sim)
 *
\*--------------------------------------------------------------------------*/


void visionInformHnd(TCA_REF_PTR ref, CoordArrayPtr c)
{
   int i,j;

   coordGrowArray(c->n, &coord);

   for(j=0; j<coord.n; j++) {
      coord.list[j].x = c->list[j].x;
      coord.list[j].y = c->list[j].y;
   }
   tcaFreeData(tcaReferenceName(ref), c);
   tcaInform(CoordInform, &coord);
/*   tcaBroadcast(CoordBroadcast, &coords);/**/
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void xyInformHnd(TCA_REF_PTR ref, XYPtr loc)
 *
 * DESCRIPTION:
 *	handle update of a single robot location (out of date)
 *
\*--------------------------------------------------------------------------*/


void xyInformHnd(TCA_REF_PTR ref, XYPtr loc)
{
   int i,n;


   coordGrowArray(loc->robot+1, &coord);

   /* move the robot */
   coord.list[loc->robot].x = loc->x;
   coord.list[loc->robot].y = loc->y;

   tcaFreeData(tcaReferenceName(ref), loc);
   /*tcaInform(CoordInform, &coord);*/
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: main()
 *
 * DESCRIPTION: 
 *
\*--------------------------------------------------------------------------*/


main()
{
   int i;

   coordInitArray(&coord);

   printf("Connect...\n");
   tcaConnectModule(MODULE, tcaServerMachine());

/*   tcaRegisterInformMessage(XYInform, XYFormat);
/*   tcaRegisterHandler(XYInform, "xyInformHnd", xyInformHnd);
/*   tcaLimitPendingMessages("VisionSim Module",1);/**/

   tcaRegisterInformMessage(VisionInform, VisionInformFormat);
   tcaRegisterHandler(VisionInform, "visionInformHnd", visionInformHnd);

   tcaWaitUntilReady();

   tcaModuleListen();

}
